## Credits

Me ([@HashNuke](https://github.com/HashNuke)), High-fever, cold, cough.

Copyright 2014 to the end of time ([MIT License](https://github.com/asdf-vm/asdf/blob/master/LICENSE))

## Maintainers

- [@HashNuke](https://github.com/HashNuke)
- [@danhper](https://github.com/danhper)
- [@Stratus3D](https://github.com/Stratus3D)
- [@vic](https://github.com/vic)
- [@jthegedus](https://github.com/jthegedus)

## Contributors

See the [list of contributors](https://github.com/asdf-vm/asdf/graphs/contributors) :pray: on GitHub
